@@ -1,6 +1,6 @@
 package MARC::Moose::Field;
-BEGIN {
-  $MARC::Moose::Field::VERSION = '0.018';
+{
+  $MARC::Moose::Field::VERSION = '0.019';
 }
 # ABSTRACT: Marc field base object
 
@@ -30,13 +30,15 @@ __PACKAGE__->meta->make_immutable;
 __END__
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MARC::Moose::Field - Marc field base object
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 SEE ALSO
 
@@ -51,11 +53,11 @@ version 0.018
 
 =head1 AUTHOR
 
-Frederic Demians <f.demians@tamil.fr>
+Frédéric Demians <f.demians@tamil.fr>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Frederic Demians.
+This software is copyright (c) 2012 by Frédéric Demians.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
