@@ -1,6 +1,6 @@
 package MARC::Moose::Parser::Legacy;
-BEGIN {
-  $MARC::Moose::Parser::Legacy::VERSION = '0.018';
+{
+  $MARC::Moose::Parser::Legacy::VERSION = '0.019';
 }
 # ABSTRACT: Parser for MARC::Record legacy records
 
@@ -43,13 +43,15 @@ __PACKAGE__->meta->make_immutable;
 __END__
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MARC::Moose::Parser::Legacy - Parser for MARC::Record legacy records
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 SYNOPSYS
 
@@ -67,11 +69,11 @@ version 0.018
 
 =head1 AUTHOR
 
-Frederic Demians <f.demians@tamil.fr>
+Frédéric Demians <f.demians@tamil.fr>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Frederic Demians.
+This software is copyright (c) 2012 by Frédéric Demians.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
