@@ -1,6 +1,6 @@
 package MARC::Moose::Parser::MarcxmlSax;
-BEGIN {
-  $MARC::Moose::Parser::MarcxmlSax::VERSION = '0.018';
+{
+  $MARC::Moose::Parser::MarcxmlSax::VERSION = '0.019';
 }
 # ABSTRACT: Parser for MARXML records using SAX parser
 
@@ -44,16 +44,23 @@ __PACKAGE__->meta->make_immutable;
 1;
 
 
+
 __END__
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MARC::Moose::Parser::MarcxmlSax - Parser for MARXML records using SAX parser
 
 =head1 VERSION
 
-version 0.018
+version 0.019
+
+=head1 DESCRIPTION
+
+Parser for MARCXML records using SAX parser.
 
 =head1 SEE ALSO
 
@@ -75,11 +82,11 @@ L<MARC::Moose::Parser::Marcxml>
 
 =head1 AUTHOR
 
-Frederic Demians <f.demians@tamil.fr>
+Frédéric Demians <f.demians@tamil.fr>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Frederic Demians.
+This software is copyright (c) 2012 by Frédéric Demians.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
