@@ -1,6 +1,6 @@
 package MARC::Moose::Parser::MarcxmlSaxSimple;
-BEGIN {
-  $MARC::Moose::Parser::MarcxmlSaxSimple::VERSION = '0.018';
+{
+  $MARC::Moose::Parser::MarcxmlSaxSimple::VERSION = '0.019';
 }
 # ABSTRACT: Parser for MARXML records using SAX::Simple parser
 
@@ -22,7 +22,7 @@ override 'parse' => sub {
     return unless $raw;
 
     my $ref = eval { $self->xs->XMLin($raw, forcearray => [ 'subfield' ] ) };
-    return undef if $@;
+    return if $@;
 
     my $record = MARC::Moose::Record->new();
     $record->_leader( $ref->{leader} );
@@ -51,13 +51,15 @@ __PACKAGE__->meta->make_immutable;
 __END__
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MARC::Moose::Parser::MarcxmlSaxSimple - Parser for MARXML records using SAX::Simple parser
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 SEE ALSO
 
@@ -79,11 +81,11 @@ L<MARC::Moose::Parser::Marcxml>
 
 =head1 AUTHOR
 
-Frederic Demians <f.demians@tamil.fr>
+Frédéric Demians <f.demians@tamil.fr>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Frederic Demians.
+This software is copyright (c) 2012 by Frédéric Demians.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
