@@ -1,6 +1,6 @@
 package MARC::Moose::Reader::File;
-BEGIN {
-  $MARC::Moose::Reader::File::VERSION = '0.018';
+{
+  $MARC::Moose::Reader::File::VERSION = '0.019';
 }
 # ABSTRACT: A reader from a file
 
@@ -12,6 +12,7 @@ use MARC::Moose::Record;
 
 extends 'MARC::Moose::Reader';
 
+
 has file => (
     is => 'rw',
     isa => 'Str',
@@ -38,7 +39,6 @@ sub BUILD {
 
 sub read {
     my $self = shift;
-
     $self->SUPER::read();
 }
 
@@ -50,13 +50,15 @@ __PACKAGE__->meta->make_immutable;
 __END__
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MARC::Moose::Reader::File - A reader from a file
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 ATTRIBUTES
 
@@ -81,11 +83,11 @@ L<MARC::Moose::Reader>
 
 =head1 AUTHOR
 
-Frederic Demians <f.demians@tamil.fr>
+Frédéric Demians <f.demians@tamil.fr>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Frederic Demians.
+This software is copyright (c) 2012 by Frédéric Demians.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
