@@ -1,6 +1,6 @@
 package MARC::Moose::Reader::File::Isis;
-BEGIN {
-  $MARC::Moose::Reader::File::Isis::VERSION = '0.018';
+{
+  $MARC::Moose::Reader::File::Isis::VERSION = '0.019';
 }
 # ABSTRACT: A file reader for ISIS (DOS) encoded records
 
@@ -14,12 +14,33 @@ use MARC::Moose::Parser::Isis;
 extends 'MARC::Moose::Reader::File';
 
 
-has parser => ( 
-    is => 'rw', 
-    isa => 'MARC::Moose::Parser',
-    default => sub { MARC::Moose::Parser::Isis->new() },
-);
 
+__END__
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+MARC::Moose::Reader::File::Isis - A file reader for ISIS (DOS) encoded records
+
+=head1 VERSION
+
+version 0.019
+
+=head1 DESCRIPTION
+
+Read next available L<MARC::Moose::Record> from reader file using
+L<MARC::Moose::Parser::Isis> parser.
+
+=head1 ATTRIBUTES
+
+=head2 parser
+
+By default, use L<MARC::Moose::Parser::Isis> to read L<MARC::Moose::Record>
+records from a file.
+
+has '+parser' => ( default => sub { MARC::Moose::Parser::Isis->new() } );
 
 override 'read' => sub {
     my $self = shift;
@@ -42,25 +63,6 @@ __PACKAGE__->meta->make_immutable;
 
 1;
 
-
-__END__
-=pod
-
-=head1 NAME
-
-MARC::Moose::Reader::File::Isis - A file reader for ISIS (DOS) encoded records
-
-=head1 VERSION
-
-version 0.018
-
-=head1 METHODS
-
-=head2 read
-
-Read next available L<MARC::Moose::Record> from reader file using
-L<MARC::Moose::Parser::Isis> parser.
-
 =head1 SEE ALSO
 
 =over 4
@@ -81,11 +83,11 @@ L<MARC::Moose::Parser::Isis>
 
 =head1 AUTHOR
 
-Frederic Demians <f.demians@tamil.fr>
+Frédéric Demians <f.demians@tamil.fr>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Frederic Demians.
+This software is copyright (c) 2012 by Frédéric Demians.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
