@@ -1,6 +1,6 @@
 package MARC::Moose::Reader::String;
-BEGIN {
-  $MARC::Moose::Reader::String::VERSION = '0.018';
+{
+  $MARC::Moose::Reader::String::VERSION = '0.019';
 }
 # ABSTRACT: A reader from a string
 
@@ -23,13 +23,15 @@ __PACKAGE__->meta->make_immutable;
 __END__
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MARC::Moose::Reader::String - A reader from a string
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 ATTRIBUTES
 
@@ -57,11 +59,11 @@ L<MARC::Moose::Reader::String::Iso2709>
 
 =head1 AUTHOR
 
-Frederic Demians <f.demians@tamil.fr>
+Frédéric Demians <f.demians@tamil.fr>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Frederic Demians.
+This software is copyright (c) 2012 by Frédéric Demians.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
