@@ -1,6 +1,6 @@
 package MARC::Moose::Reader::String::Iso2709;
-BEGIN {
-  $MARC::Moose::Reader::String::Iso2709::VERSION = '0.018';
+{
+  $MARC::Moose::Reader::String::Iso2709::VERSION = '0.019';
 }
 # ABSTRACT: File reader for MARC::Moose record from ISO2709 string
 
@@ -59,21 +59,23 @@ __PACKAGE__->meta->make_immutable;
 __END__
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MARC::Moose::Reader::String::Iso2709 - File reader for MARC::Moose record from ISO2709 string
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 AUTHOR
 
-Frederic Demians <f.demians@tamil.fr>
+Frédéric Demians <f.demians@tamil.fr>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Frederic Demians.
+This software is copyright (c) 2012 by Frédéric Demians.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
